0.4.0
-----
- 项目更名： tikcets -> iquery
- 新功能：查询莆田系医院
- 统一了每个服务的接口

0.3.0
------
- 新功能，查询热映电影信息及电影简介
- 优化火车查询日期处理，本年内不需要输入年
- 小bug修复

0.2.4
------
- 修正Windows下面的编码问题
- 修正查询show时不支持城市报错问题

0.2.3
------
- 不再使用colorama
- 改变显示演出的方式

0.2.2
------
- 小bug修复

0.2.1
------
- setup缺失colorama修复

0.2.0
------
- 不再支持Python2
- 重构了代码
- 增加的查询演出门票的功能

0.1.1
------

- use unicode global
- add a logo

0.1.0
------

- Make it live!
- Added to PyPI
